==> ejc-ztpcct-impl-3.0.0-20231008.063616-38-sources.jar: com/ejianc/ztpc/bean/ConstructionSchemeEntity.java <==
package com.ejianc.ztpc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.Date;
import java.util.List;

/**
 * 施工方案表
 *
 * @author generator
 */
@TableName("ct_construction_scheme")
public class ConstructionSchemeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "code")
    private String code; // 编码
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "org_id")
    private Long orgId; // 项目组织ID
    @TableField(value = "org_code")
    private String orgCode; // 项目组织编码
    @TableField(value = "org_name")
    private String orgName; // 项目组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 父级组织ID
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value = "cons_scheme_id")
    private Long consSchemeId; // 施工方案ID
    @TableField(value = "cons_scheme_name")
    private String consSchemeName; // 施工方案名称
    @TableField(value = "cons_scheme_type")
    private Long consSchemeType; // 施工方案类别--字典ct_cons_scheme_type
    @TableField(value = "engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value = "specialty_type")
    private Long specialtyType; // 专业分类--字典ct_specialty_type
    @TableField(value = "project_leave")
    private Long projectLeave; // 项目分级(自定义档案)
    @TableField(value = "execute_state")
    private String executeState; // 执行状态
    @TableField(value = "execute_state_name")
    private String executeStateName; // 执行状态名称
    @TableField(value = "approval_power")
    private String approvalPower; // 批准权限
    @TableField(value = "plan_redact_date")
    private Date planRedactDate; // 计划编制时间
    @TableField(value = "redact_finish_date")
    private Date redactFinishDate; // 编制完成时间
    @TableField(value = "org_expert_examine")
    private String orgExpertExamine; // 组织专家审查要求（Y：是，N：否）
    @TableField(value = "cons_time_frame")
    private String consTimeFrame; // 施工时段
    @TableField(value = "finish_cons_scheme_date")
    private Date finishConsSchemeDate; // 完成施工方案时间
    @TableField(value = "project_trait")
    private Long projectTrait; // 分部分项工程特征--字典ct_project_trait
    @TableField(value = "key_point_explain")
    private String keyPointExplain; // 专项施工方案关注重点
    @TableField(value = "file_version")
    private String fileVersion; // 文件版次
    @TableField(value = "text_attachment")
    private String textAttachment; // 正文附件
    @TableField(value = "project_manage_type")
    private Long projectManageType; // 项目管理分类--字典ct_project_manage_type状态名称
    @TableField(value = "file_state")
    private String fileState; // 文件状态（Y：有效，N：无效）
    @TableField(value="expert_argument_file")
    private String expertArgumentFile; // 专项方案专家论证报告附件

    @TableField(exist = false)
    @SubEntity(serviceName = "opinionInfoService")
    private List<OpinionInfoEntity> opinionInfoList; // 意见栏

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Long getConsSchemeId() {
        return consSchemeId;
    }

    public void setConsSchemeId(Long consSchemeId) {
        this.consSchemeId = consSchemeId;
    }

    public String getConsSchemeName() {
        return consSchemeName;
    }

    public void setConsSchemeName(String consSchemeName) {
        this.consSchemeName = consSchemeName;
    }

    public Long getConsSchemeType() {
        return consSchemeType;
    }

    public void setConsSchemeType(Long consSchemeType) {
        this.consSchemeType = consSchemeType;
    }

    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }

    public Long getSpecialtyType() {
        return specialtyType;
    }

    public void setSpecialtyType(Long specialtyType) {
        this.specialtyType = specialtyType;
    }

    public Long getProjectLeave() {
        return projectLeave;
    }

    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }

    public String getExecuteState() {
        return executeState;
    }

    public void setExecuteState(String executeState) {
        this.executeState = executeState;
    }

    public String getExecuteStateName() {
        return executeStateName;
    }

    public void setExecuteStateName(String executeStateName) {
        this.executeStateName = executeStateName;
    }

    public String getApprovalPower() {
        return approvalPower;
    }

    public void setApprovalPower(String approvalPower) {
        this.approvalPower = approvalPower;
    }

    public Date getPlanRedactDate() {
        return planRedactDate;
    }

    public void setPlanRedactDate(Date planRedactDate) {
        this.planRedactDate = planRedactDate;
    }

    public Date getRedactFinishDate() {
        return redactFinishDate;
    }

    public void setRedactFinishDate(Date redactFinishDate) {
        this.redactFinishDate = redactFinishDate;
    }

    public String getOrgExpertExamine() {
        return orgExpertExamine;
    }

    public void setOrgExpertExamine(String orgExpertExamine) {
        this.orgExpertExamine = orgExpertExamine;
    }

    public String getConsTimeFrame() {
        return consTimeFrame;
    }

    public void setConsTimeFrame(String consTimeFrame) {
        this.consTimeFrame = consTimeFrame;
    }

    public Date getFinishConsSchemeDate() {
        return finishConsSchemeDate;
    }

    public void setFinishConsSchemeDate(Date finishConsSchemeDate) {
        this.finishConsSchemeDate = finishConsSchemeDate;
    }

    public Long getProjectTrait() {
        return projectTrait;
    }

    public void setProjectTrait(Long projectTrait) {
        this.projectTrait = projectTrait;
    }

    public String getKeyPointExplain() {
        return keyPointExplain;
    }

    public void setKeyPointExplain(String keyPointExplain) {
        this.keyPointExplain = keyPointExplain;
    }

    public String getFileVersion() {
        return fileVersion;
    }

    public void setFileVersion(String fileVersion) {
        this.fileVersion = fileVersion;
    }

    public String getTextAttachment() {
        return textAttachment;
    }

    public void setTextAttachment(String textAttachment) {
        this.textAttachment = textAttachment;
    }

    public Long getProjectManageType() {
        return projectManageType;
    }

    public void setProjectManageType(Long projectManageType) {
        this.projectManageType = projectManageType;
    }

    public List<OpinionInfoEntity> getOpinionInfoList() {
        return opinionInfoList;
    }

    public void setOpinionInfoList(List<OpinionInfoEntity> opinionInfoList) {
        this.opinionInfoList = opinionInfoList;
    }

    public String getFileState() {
        return fileState;
    }

    public void setFileState(String fileState) {
        this.fileState = fileState;
    }

    public String getExpertArgumentFile() {
        return expertArgumentFile;
    }

    public void setExpertArgumentFile(String expertArgumentFile) {
        this.expertArgumentFile = expertArgumentFile;
    }
}

==> ejc-ztpcct-impl-3.0.0-20231009.110533-44-sources.jar: com/ejianc/ztpc/bean/ConstructionSchemeEntity.java <==
package com.ejianc.ztpc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import java.util.Date;
import java.util.List;

/**
 * 施工方案表
 *
 * @author generator
 */
@TableName("ct_construction_scheme")
public class ConstructionSchemeEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "code")
    private String code; // 编码
    @TableField(value = "bill_state")
    private Integer billState; // 单据状态：0自由态，1已提交，2审批中，3审批通过，4驳回，5提交后有人审批中
    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "org_id")
    private Long orgId; // 项目组织ID
    @TableField(value = "org_code")
    private String orgCode; // 项目组织编码
    @TableField(value = "org_name")
    private String orgName; // 项目组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 父级组织ID
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 父级组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 父级组织名称
    @TableField(value = "cons_scheme_id")
    private Long consSchemeId; // 施工方案ID
    @TableField(value = "cons_scheme_name")
    private String consSchemeName; // 施工方案名称
    @TableField(value = "cons_scheme_type")
    private Long consSchemeType; // 施工方案类别--字典ct_cons_scheme_type
    @TableField(value = "engineering_type_id")
    private Long engineeringTypeId; // 工程类别
    @TableField(value = "specialty_type")
    private Long specialtyType; // 专业分类--字典ct_specialty_type
    @TableField(value = "project_leave")
    private Long projectLeave; // 项目分级(自定义档案)
    @TableField(value = "execute_state")
    private String executeState; // 执行状态
    @TableField(value = "execute_state_name")
    private String executeStateName; // 执行状态名称
    @TableField(value = "approval_power")
    private Long approvalPower; // 批准权限
    @TableField(value = "plan_redact_date")
    private Date planRedactDate; // 计划编制时间
    @TableField(value = "redact_finish_date")
    private Date redactFinishDate; // 编制完成时间
    @TableField(value = "org_expert_examine")
    private String orgExpertExamine; // 组织专家审查要求（Y：是，N：否）
    @TableField(value = "cons_time_frame")
    private String consTimeFrame; // 施工时段
    @TableField(value = "finish_cons_scheme_date")
    private Date finishConsSchemeDate; // 完成施工方案时间
    @TableField(value = "project_trait")
    private Long projectTrait; // 分部分项工程特征--字典ct_project_trait
    @TableField(value = "key_point_explain")
    private String keyPointExplain; // 专项施工方案关注重点
    @TableField(value = "file_version")
    private String fileVersion; // 文件版次
    @TableField(value = "text_attachment")
    private String textAttachment; // 正文附件
    @TableField(value = "project_manage_type")
    private Long projectManageType; // 项目管理分类--字典ct_project_manage_type状态名称
    @TableField(value = "file_state")
    private String fileState; // 文件状态（Y：有效，N：无效）
    @TableField(value="expert_argument_file")
    private String expertArgumentFile; // 专项方案专家论证报告附件

    @TableField(exist = false)
    @SubEntity(serviceName = "opinionInfoService")
    private List<OpinionInfoEntity> opinionInfoList; // 意见栏

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

    public Long getConsSchemeId() {
        return consSchemeId;
    }

    public void setConsSchemeId(Long consSchemeId) {
        this.consSchemeId = consSchemeId;
    }

    public String getConsSchemeName() {
        return consSchemeName;
    }

    public void setConsSchemeName(String consSchemeName) {
        this.consSchemeName = consSchemeName;
    }

    public Long getConsSchemeType() {
        return consSchemeType;
    }

    public void setConsSchemeType(Long consSchemeType) {
        this.consSchemeType = consSchemeType;
    }

    public Long getEngineeringTypeId() {
        return engineeringTypeId;
    }

    public void setEngineeringTypeId(Long engineeringTypeId) {
        this.engineeringTypeId = engineeringTypeId;
    }

    public Long getSpecialtyType() {
        return specialtyType;
    }

    public void setSpecialtyType(Long specialtyType) {
        this.specialtyType = specialtyType;
    }

    public Long getProjectLeave() {
        return projectLeave;
    }

    public void setProjectLeave(Long projectLeave) {
        this.projectLeave = projectLeave;
    }

    public String getExecuteState() {
        return executeState;
    }

    public void setExecuteState(String executeState) {
        this.executeState = executeState;
    }

    public String getExecuteStateName() {
        return executeStateName;
    }

    public void setExecuteStateName(String executeStateName) {
        this.executeStateName = executeStateName;
    }

    public Long getApprovalPower() {
        return approvalPower;
    }

    public void setApprovalPower(Long approvalPower) {
        this.approvalPower = approvalPower;
    }

    public Date getPlanRedactDate() {
        return planRedactDate;
    }

    public void setPlanRedactDate(Date planRedactDate) {
        this.planRedactDate = planRedactDate;
    }

    public Date getRedactFinishDate() {
        return redactFinishDate;
    }

    public void setRedactFinishDate(Date redactFinishDate) {
        this.redactFinishDate = redactFinishDate;
    }

    public String getOrgExpertExamine() {
        return orgExpertExamine;
    }

    public void setOrgExpertExamine(String orgExpertExamine) {
        this.orgExpertExamine = orgExpertExamine;
    }

    public String getConsTimeFrame() {
        return consTimeFrame;
    }

    public void setConsTimeFrame(String consTimeFrame) {
        this.consTimeFrame = consTimeFrame;
    }

    public Date getFinishConsSchemeDate() {
        return finishConsSchemeDate;
    }

    public void setFinishConsSchemeDate(Date finishConsSchemeDate) {
        this.finishConsSchemeDate = finishConsSchemeDate;
    }

    public Long getProjectTrait() {
        return projectTrait;
    }

    public void setProjectTrait(Long projectTrait) {
        this.projectTrait = projectTrait;
    }

    public String getKeyPointExplain() {
        return keyPointExplain;
    }

    public void setKeyPointExplain(String keyPointExplain) {
        this.keyPointExplain = keyPointExplain;
    }

    public String getFileVersion() {
        return fileVersion;
    }

    public void setFileVersion(String fileVersion) {
        this.fileVersion = fileVersion;
    }

    public String getTextAttachment() {
        return textAttachment;
    }

    public void setTextAttachment(String textAttachment) {
        this.textAttachment = textAttachment;
    }

    public Long getProjectManageType() {
        return projectManageType;
    }

    public void setProjectManageType(Long projectManageType) {
        this.projectManageType = projectManageType;
    }

    public List<OpinionInfoEntity> getOpinionInfoList() {
        return opinionInfoList;
    }

    public void setOpinionInfoList(List<OpinionInfoEntity> opinionInfoList) {
        this.opinionInfoList = opinionInfoList;
    }

    public String getFileState() {
        return fileState;
    }

    public void setFileState(String fileState) {
        this.fileState = fileState;
    }

    public String getExpertArgumentFile() {
        return expertArgumentFile;
    }

    public void setExpertArgumentFile(String expertArgumentFile) {
        this.expertArgumentFile = expertArgumentFile;
    }
}
